using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Utils.Logs;
using System.Diagnostics;

namespace WLog.GUI
{
    /// <summary>
    /// Component which uses a ListView to displays the log entries
    /// </summary>
    public partial class fr_ListView : Form
    {
        #region Variables
        private LogSet vLogSet = new LogSet();
        #endregion

        #region Constructors
        /// <summary>
        /// Constructors
        /// </summary>
        public fr_ListView() { InitializeComponent(); }
        #endregion

        #region Events
        /// <summary>
        /// Frame is loading
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_FrameLoad(object sender, EventArgs e)
        {
            MessageBox.Show("Path: " + Log.Instance.FileToLog);
            Stopwatch sw = new Stopwatch();
            sw.Start();
            LogSet ls = new LogSet(Log.Instance.FileToLog);
            ls.Fill();
            sw.Stop();
            MessageBox.Show("Time = " + sw.Elapsed.Minutes + " min " + sw.Elapsed.Seconds + " sec " 
                + sw.Elapsed.Milliseconds + " msec! " + ls.Count + " elem");

            sw.Reset();
            sw.Start();
            dgv.DataSource = ls.List;
            sw.Stop();
            MessageBox.Show("Time = " + sw.Elapsed.Minutes + " min " + sw.Elapsed.Seconds + " sec "
                + sw.Elapsed.Milliseconds + " msec! " + ls.Count + " elem");

            SetDisplayedLogs(dgv);
        }
        /// <summary>
        /// Set the DataGridView
        /// </summary>
        /// <param name="_dgv"></param>
        private void SetDisplayedLogs(DataGridView _dgv)
        {
            _dgv.Columns["ID"].Visible = false;
            _dgv.Columns["Date"].Visible = false;
            _dgv.Columns["ParsedDate"].DisplayIndex = 0;
            _dgv.Columns["ParsedDate"].HeaderText = "Date";
            _dgv.Columns["Type"].DisplayIndex = 1;
            _dgv.Columns["Title"].DisplayIndex = 2;
            _dgv.Columns["Message"].DisplayIndex = 3;
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the LogSet with the log entries
        /// </summary>
        public LogSet LogSet
        {
            get { return vLogSet; }
            set { vLogSet = value; }
        }
        #endregion
    }
}